## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::Fa v1.1.5;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::Fa::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg Fa

=head1 NAME

TeX::Hyphen::Pattern::Fa - class for hyphenation in locale Fa

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text

title: (No) Hyphenation patterns for Persian
copyright: Copyright (C) Arthur Reutenauer 2018
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.
language:
    name: Persian
    tag: fa
version: 0
authors:
    - Arthur Reutenauer
licence:
    -
       name: MIT
hyphenmins:
    typesetting:
        left:
        right:
texlive:
    babelname: farsi
    synonyms:
        - persian
    use_old_loader: true
    legacy_patterns: zerohyph.tex
    message:
    description: Prevent hyphenation in Persian.

=end text

=cut

__DATA__


