## no critic qw(RequirePodSections)    # -*- cperl -*-
# This file is auto-generated by the Perl TeX::Hyphen::Pattern Suite hyphen
# pattern catalog generator. This code generator comes with the
# TeX::Hyphen::Pattern module distribution in the tools/ directory
#
# Do not edit this file directly.

package TeX::Hyphen::Pattern::La_x_liturgic v1.1.5;
use strict;
use warnings;
use 5.014000;
use utf8;

use Moose;

my $pattern_file = q{};
while (<DATA>) {
    $pattern_file .= $_;
}

sub pattern_data {
    return $pattern_file;
}

sub version {
    return $TeX::Hyphen::Pattern::La_x_liturgic::VERSION;
}

1;
## no critic qw(RequirePodAtEnd RequireASCII ProhibitFlagComments)

=encoding utf8

=for stopwords CTAN Ipenburg La_x_liturgic

=head1 NAME

TeX::Hyphen::Pattern::La_x_liturgic - class for hyphenation in locale La_x_liturgic

=head1 SUBROUTINES/METHODS

=over 4

=item $pattern-E<gt>pattern_data();

Returns the pattern data.

=item $pattern-E<gt>version();

Returns the version of the pattern package.

=back

=head1 COPYRIGHT

=begin text

copyright: Copyright (C) 2016-2019 Claudio Beccari, Elie Roux
title: Hyphenation patterns for liturgical Latin
notice: This file is part of the hyph-utf8 package.
    See http://www.hyphenation.org/tex for more information.
language:
    name: Liturgical Latin
    tag: la-x-liturgic
version: 2019-02-04
authors:
    -
        name: Claudio Beccari
        contact: claudio.beccari (at) gmail.com
    -
        name: Monastery of Solesmes
        contact: adecastelbajac (at) gmx.com
    -
        name: Élie Roux
        contact: elie.roux (at) telecom-bretagne.eu
licence:
  -
    name: MIT
    url: https://opensource.org/licenses/MIT
    text: >
        Permission is hereby granted, free of charge, to any person obtaining
        a copy of this software and associated documentation files (the
        "Software"), to deal in the Software without restriction, including
        without limitation the rights to use, copy, modify, merge, publish,
        distribute, sublicense, and/or sell copies of the Software, and to
        permit persons to whom the Software is furnished to do so, subject to
        the following conditions:

        The above copyright notice and this permission notice shall be
        included in all copies or substantial portions of the Software.

        THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
        EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
        MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
        NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
        BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
        ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
        CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
        SOFTWARE.
hyphenmins:
    typesetting:
        left: 2
        right: 2
texlive:
    encoding: ec
    babelname: liturgicallatin
    message: Liturgical Latin hyphenation patterns
    package: latin

=end text

=cut

__DATA__
\patterns{
.a3b3æq
.a2b1ali
.a2b1auu
.a2b3c
.a2b1eo
.á2b1eo
.a2b1er
.a2b1ér
.á2b1er
.a4b3es
.a4b3és
.a2b1e3u
.á2b1e3u
.a2b1e3ú
.a2b1é3u
.a2bf
.a2b1í
.a2b1ic
.a2b1i2ec
.a2b1i2éc
.a2b3ier
.a2b3iér
.a2b1ig
.á2b3ig
.a2b1i2i
.a2b1i2í
.á2b1i2i
.a2b1in1
.a2b1ir
.a2b1it
.á2b1it
.a2b1i4u
.a2b1i4ú
.a2b1iv
.a2bj
.a2b3l
.á2b3lu
.a2b1ol
.a2b1ól
.a2b1om
.a2b1or
.a2b1ór
.a2b1ort
.a2b3r
.á2b3r
.a3b4rah
.á3b4rah
.a2b3ru
.ab4s3temi
.ab4s3témi
.ab5s4temini.
.ab5s4témini.
.ab4s3ten
.ab4s3tén
.ab5s4tent.
.ab5s4tentur.
.ab5s4téntur.
.ab4s3terg
.ab4s3térg
.ab4s3terr
.ab4s3térr
.ab4s3ters
.ab4s3térs
.ab4s3tol
.ab4s3tól
.ab4s3trah
.ab4s3tráh
.áb4s3trah
.ab4s3tras
.ab4s3trás
.ab4s3trax
.ab4s3tráx
.ab4s3tru
.ab4s3trú
.áb4s3tru
.ab4s3tu
.ab4s3tú
.áb4s3tu
.absu2b3l
.absú2b3l
.a2b3und
.a2b3únd
.a2b3us
.a2b3ut
.a2b3út
.a2d3
.á2d3
.a3d4æ
.a4d5æq
.a3d4am.
.a3d4amant
.a2d3a3s4cr
.a3d4eps
.ader2
.ade3u
.a2dfu
.adi2a
.ádi2a
.adi2á
.a3d4i3ab
.a3d4i3áb
.adi2e
.adi2é
.adi3en
.adi3én
.ad3i2i
.ad3i2í
.adi2o
.ádi2o
.a3d4ip
.a3d4íp
.á3d4ip
.a4d5ipisc
.a4d5ipísc
.ad5is.
.ad5it.
.ad3i2u
.ad3i2ú
.ádi2u
.ado2b3
.adó2b3
.a4d3ole
.a3d4on
.a3d4ón
.a3d4ramy
.a3d4ran
.a3d4rán
.á3d4ran
.ad3s2cr
.ad3si
.a2d5s2t
.á2d5s2tr
.adsu3e
.a3d4u3a
.a3d4u3á
.a4d5ul
.a3d4urn
.a3d4y
.a3d4ý
.á3d4y
.alte3r
.alté3r
.álte3r
.alte4rc
.alté4rc
.alte4rn
.alté4rn
.alte4rp
.alté4rp
.alte4rt
.alté4rt
.alte4r3ut
.alté4r3ut
.alte4r3út
.am2b3a2d3
.am2b3á2d3
.am2b3ag
.ám2b3ag
.am2b3ág
.am2b3arv
.am2b3ax
.am2b3áx
.am2b3ed
.ám2b3ed
.am2b3éd
.am2b3es
.am2b3és
.am2b3i
.ám2b3i
.am2b3í
.am3b4iani
.am3b4iáni
.am3b4iano
.am3b4iáno
.am3b4ianó
.am3b4iatin
.am3b4iatín
.am3b4ibar
.am3b4ibár
.am3b4ic
.am3b4íc
.am3b4id
.ám3b4id
.ambi2ec
.ambi2éc
.am3b4ieg
.am3b4iég
.am3b4if
.am3b4igene
.am3b4igéne
.am3b4igené
.am3b4igenus.
.am3b4ígenus.
.am3b4il
.am3b4íl
.am3b4ima
.am3b4íma
.am3b4iori
.am3b4iorí
.am3b4íori
.am3b4isin
.am3b4iso
.am3b4isó
.am3b4itex
.am3b4itéx
.am3b4itr
.am3b4itut
.am3b4ítut
.am3b4iva
.am3b4ivia
.am3b4ívia
.am3b4ivie
.am3b4ívie
.am3b4ivii
.am3b4ívii
.am3b4ivio
.am3b4ivió
.am3b4ívio
.am3b4iviu
.am3b4íviu
.am3b4ix.
.am2b3ur
.am2b3úr
.am2b3us
.am2b3ús
.ani2m3ad
.ante3u
.anti1
.anti3m2n
.ape3r2u
.archi3e
.a3s2c
.á3s2c
.a3s4pu
.a3s4pú
.á3s4pu
.a6s5plen
.a6s5plén
.a6s5purg
.a6s5púrg
.a3s2t
.á3s2t
.a4sthm
.a4s3tr
.á4s3tr
.a5s4trat
.a5s4trát
.a5s4trid
.a5s4tríd
.a5s4tru
.á5s4tru
.a5s4trú
.a6s5trum.
.b2
.beni4a
.béni4a
.be4th5l
.bé4th5l
.bou6s5tr
.c2
.circu4m1
.circú4m1
.circumam2b3
.circumám2b3
.circumam3b4ul
.circumam3b4úl
.circumám3b4ul
.circume3u
.circume3ú
.circumi2a
.circumi2á
.circumi2e
.circumi2é
.circumi2i
.circumi2í
.circumi2n3i4i
.circumi2n3i4í
.circumi2o
.circumi2u
.circumo2b3
.circumó2b3
.circum5s4
.circú4m5s4
.ci2s3
.co1e
.co3e2lec
.co3e2lig
.co3emen
.co2e1n
.co3e2r
.co3e2x3
.coex3s2
.co3g2nos
.co3g2nós
.co1i
.co1i2e
.coi3u
.co2m3ed
.co2m3éd
.có2m3ed
.co2m3es.
.co2m3it
.co2m3ít
.có2m3it
.co2n1
.có2n1
.co3n2a
.co3n2á
.co3n2e
.co3n2é
.co3n2i
.co3n2í
.coni2a
.con3ic
.conde3s4p
.coni2e
.co6n5i4ec
.co6n5i4éc
.co6n3i4i
.co6n3i4í
.co4n3i2u
.co4n3i2ú
.có4n3i2u
.co3n2o
.co3n2ó
.con3s2cr
.cón3s2cr
.con3s4p
.cón3s4p
.co3n2u
.co3n2ú
.cre3u
.cu4ll
.cu4mm
.cu4sp
.cú4sp
.de1í
.dé1i
.de1in
.de1ín
.de1it
.depe4r5
.depé4r5
.dépe4r5
.de3s2c
.de3s4p
.dé3s4p
.de3s2q
.de3s2t
.dé3s2t
.de3u
.de4uc
.de4ul
.de4urio
.de4urío
.de4uter.
.de4utera
.de4uterá
.de4uteræ
.de4uteri
.de4utéri
.de5uteris.
.de5utéris.
.de4utero
.de4uteró
.de4uteru
.dia3s4p
.di3g2nosc
.di3i4u
.di3i4ú
.di3œ
.di2r1im
.di2r1ím
.di5s4ced
.di5s4céd
.di5s4cen
.di5s4cén
.di5s4cep
.di5s4cép
.di5s4cer
.di5s4cér
.di5s4ces
.di5s4cés
.di5s4cid
.di5s4cíd
.di5s4cin
.di5s4cín
.di5s4cip
.di5s4cíp
.di5s4ciss
.di5s4císs
.di5s4cit
.dí5s4cit
.di5s4cr
.di6s5cre
.di6s5cré
.di6s5crim
.di6s5crím
.di6s5cru
.di6s5cruc
.di6s5crúc
.di5s4ert
.di5s4ért
.di2s1i2
.di2s1í2
.disi3c
.disí3c
.di2sj
.dispe2r3
.dispé2r3
.di5s4ta
.di5s4tá
.di5s4tin
.di5s4tín
.di6s5tine
.di6s5tíne
.di5s4tir
.di5s4tír
.di5s4to.
.di5s4trar
.di5s4trár
.di5s4trat
.di5s4trát
.di5s4trav
.di5s4tráv
.di3u
.di3ú
.dy6s5p6n
.ei5on
.ele3usa
.ele3usæ
.e2t3en
.é2t3en
.e2t3i3am
.é2t3i3am
.e2t3i3ám
.e3u3ax.
.e3ú3ax.
.eu3s2tom
.eu3s2tóm
.eu3s2ty
.eu3s2tý
.e2x3
.é2x3
.exam2b3i
.exam2b3í
.exám2b3i
.e3x4ed
.é3x4ed
.e3x4éd
.e3x4eget
.e3x4egét
.exo2b3
.exó2b3
.e3x4od
.é3x4od
.e3x4ód
.e3x4orc
.e3x4ost
.e3x4óst
.ex5s4c
.éx5s4c
.ex3s4p
.éx3s4p
.ex5s2t
.éx5s2t
.f2
.g2
.gai4
.h2
.he3i.
.hi2e
.hi2é
.hucu4s
.hu1i2u
.hu1i2ú
.i4a
.i4á
.iai2u
.i3bi
.i3bí
.i3bo
.i3bó
.i3bu
.i3bú
.i3co
.i3có
.i2d1
.i2dci
.i3d2e
.i3d2é
.í3d2e
.i4d3em
.i5den
.i4d3eo.
.í4d3eo.
.i4d3eoq
.i4d3eóq
.i4d3es
.i3d2ib
.i3di2og
.i3d2ol
.i3d2ól
.i3d2on
.i3d2ón
.i3d2us
.i2e
.i2é
.iei2u
.i3i
.i3í
.í3i
.i4n3
.í4n3
.ina2b3r
.inab3s2
.ina2cr
.ina2df
.i3n2an
.i3n2án
.incircu4m
.incon5s4tr
.incón5s4tr
.in4d3ep
.in4d3ép
.in4d3ig
.ín4d3ig
.in5d4ign
.in5d4ígn
.in4d3ipis
.in4d3ipís
.in5d4is
.in4d3u
.ín4d3u
.in4d3ú
.in5d4u.
.in5d4ub
.in5d4úb
.in5d4uc
.in5d4úc
.in6d5ucul
.in6d5úcul
.in5d4ug
.in5d4ul
.in5d4úl
.in5d4up
.in5d4ur
.in5d4úr
.ín5d4ur
.in5d4us.
.in5d4u5s4tr
.in5d4ú5s4tr
.in5d4utiæ
.in5d4útiæ
.in5d4utia
.in5d4utiá
.in5d4útia
.in5d4utii
.in5d4útii
.in5d4utio
.in5d4utió
.in5d4ux
.in5d4úx
.i3n2ers
.i3n2ert
.ine2x3
.inexs2t
.infra3s4
.ini2e
.ini2é
.ini2í
.i3n2it
.ini2u
.ini2ú
.ino2b3
.inó2b3
.inobi6ur
.inpe2r3iur
.in3s4cr
.in3s4p
.ín3s4p
.in5s2t
.ín5s2t
.inte2r3e
.inte2r3é
.inté2r3e
.inte3r4em
.inte3r4ém
.inte3r4en
.inte3r4én
.inte3r4er
.inté3r4er
.inte3r4ér
.inte3r4es
.inte4r5ess
.inte3r4et
.inte3r4ét
.inte2r3i
.inte2r3í
.inté2r3i
.ínte2r3i
.interi2a
.interi2á
.interi2e
.interí2e
.interi2é
.interi2i
.interi2í
.inte3r4i3or
.inte3r4i3ór
.inté3r4i3or
.interi2u
.interi2ú
.inte3r4ius.
.inté3r4ius.
.inter3s4p
.inter5s4t
.intér5s4t
.intran2s1
.intro3i3e
.intro3i3é
.inu2a
.inu2e
.inu2i
.i3n2ul
.i4n3ulc
.inu2o
.inu2u
.i2o
.i2ó
.i4u
.i4ú
.i5ul
.i5úl
.i6uli
.i6úli
.i7uli.
.i7úli.
.i7ulid
.i7úlid
.i7ulis.
.i7úlis.
.iu2s3i2ur
.j2
.l2
.langu4ere.
.langu4ére.
.langu4eri.
.langu4éri.
.la4u
.lecti5s4t
.lon2g1an
.lon2g1án
.lu4x3q
.lu3x2u
.lu3x2ú
.m2
.mai4u
.n2
.ne2c1op
.ne2c1óp
.ne2g1ot
.ne2g1ót
.ne3ut
.né3ut
.o2b3
.ó2b3
.o3b4el
.ó3b4el
.obi2ac
.obi2ác
.obi2ec
.obi2éc
.obi2ic
.obi2íc
.óbi2ic
.o3b4il
.o3b4íl
.obi2ur
.obi2úr
.o3b4ol
.ó3b4ol
.o4b5ole
.o4b5olé
.ó4b5ole
.o3b4rim
.o3b4russ
.o3b4rúss
.o3b4ryz
.o3b4rýz
.ob3s2q
.ob5st
.ób5st
.p2
.pæ2n3ins
.pæ2n3íns
.para1i
.para1u
.par3s4tr
.pe1i6or
.pe1i6ór
.pe2r1abs
.pe2r1ac
.pe2r1ác
.pe2r1a2dp
.pe2r1a2d1u
.pe2r1ae
.pe2r3ag
.pe2r3ág
.pé2r3ag
.pe2r1ama
.pe2r1amá
.pe2r1amb
.pe2r1ámb
.pe4r3ant
.pe2r1ar
.pe2r1ár
.pe2r1a2u
.pe2r1coq
.pe2r1cu
.pe2r3ea
.pe2r3eám
.pé2r3eam
.pé2r3eant
.pe2r3eát
.pé2r3eat
.pe2r3eas
.pé2r3eas
.pe4r3ec
.pe4r1ed
.pe2r1eff
.pe2r3ég
.pe2r3eg
.pe6r3egr
.pé6r3egr
.pe2r1el
.pe2r1em
.pe2r1ém
.pe4r5end
.pe4r5énd
.pe4r3enn
.pe4r3énn
.pe2r3eo
.pé2r3eo
.pe4r3err
.pe4r3érr
.pe2r1eru
.pe2r3es.
.pe4r1e2x3
.pe2r3h
.pé2r3h
.pe2r3i1
.pe2r3í1
.pe3r4ia
.pe3r4iá
.pe2r1i2ac
.pe3r4ian
.pe2r3ib
.pe2r3íb
.pe3r4icl
.pe3r4ícl
.pe3r4icu
.pe3r4ícu
.pe2r3ie
.pe2r3íe
.pe2r3ié
.pe3r4ieb
.pe3r4iéb
.pe3r4iem
.pe3r4iém
.pe3r4ien
.pe3r4ién
.pe4r5iens
.pé4r5iens
.pe3r4ier
.pe3r4íer
.pe3r4iér
.pe4r5iera
.pé4r5iera
.pe4r5íera
.pe5r6ierat
.pé5r6ierat
.pe5r6íerat
.perie3i
.pe3r4iet
.pe3r4iét
.perié3i
.períe3i
.pe2r1i2ec
.pé2r3ii
.per5iit
.pér5iit
.pe3r4ileu
.pe3r4iléu
.pe4r3im
.pe4r3ím
.pé4r3im
.pe5r4imed
.pe5r4imi
.pe5r4ími
.pe5r4imu
.pe5r4ímu
.pe6r5imus
.pe6r5ímus
.pe2r3in
.pe2r3ín
.pe3r4int
.pe3r4ínt
.pe3r4io
.pe3r4iod
.pe3r4íod
.pe3r4iód
.pe5r4ip
.pe2r3ir
.pe5r4irr
.pe3r4iremur
.pe3r4irémur
.pe3r4iremi
.pe3r4irémi
.pe3r4irentur
.pe3r4iréntur
.pe3r4irer
.pe3r4irér
.pe3r4írer
.pe3r4iret
.pe3r4irét
.pe4r5iret.
.pe4r5iretis
.pe4r5irétis
.pe3r4iri
.pe3r4íri
.pe3r4i3s2c
.pe3r4í3s2c
.pe5r4isseu
.pe5r4isséu
.pe3r4i3st
.pe3r4í3st
.pe3r4it
.pe3r4ít
.pe4r5itúr
.pe4r5itur
.pe4r5ítur
.pe4r5it.
.pe4r5itote
.pe4r5itóte
.pe2r3i4u
.pé2r3i4u
.pe2r3i4ú
.pe3r4i5un
.pe3r4i5ún
.pe4r3j
.pé4r3j
.pe2r1o2b
.pe2r1od
.pe2r1of
.pe2r1ol
.pe2r1op
.pe4r3or
.pe4r3ór
.pe2r3reg
.pe2r3s2c
.pe2r3s2t
.pé2r3s2t
.pe2r3tran2s1
.pe2r3trán2s1
.pe2r3u
.pe2r3ú
.pe2r1u2a
.pe2r1u2e
.pe2r1u2i
.pe3r4ul
.pe3r4úl
.pe2r1u2o
.po3et
.pos4t3ea
.pos4t3eá
.pós4t3ea
.pos4t3er
.pos4t3ér
.pós4t3er
.pos5t4erg
.pos4t3h
.po4s4t3hac
.pos4t3il
.pos4t3íl
.posu3í
.pósu3i
.po2t3e
.po2t3é
.pó2t3e
.po4t3ue
.po4t3ui
.po4t3úe
.po4t3úi
.po4t3ué
.po4t3uí
.pó4t3ui
.præ1
.præ3a2u
.præ3es
.præe2x1
.præé2x1
.præi4a
.præi4á
.præi4ec
.præin3s4t
.præín3s4t
.præi4o
.præi4i
.præi4í
.præi4u
.præi4ú
.præ3s2c
.præ5s2t
.prǽ5s2t
.præte2r1
.præté2r1
.primi1
.primi3s2c
.pro2d1ea
.pró2d1ea
.pro3d2eamb
.pro2d1eo
.pró2d1eo
.pro2d1es3s
.pro2d1és3s
.pro2d1e3un
.pró2d1e3un
.pro2d1fu2
.pro2d1ib
.pro3d2i3d
.pro3d2í3d
.pro2d1ien
.pro2d1ién
.pró2d1ien
.pro2d1ier
.pro2d1iér
.pró2d1ier
.pro2d1ig
.pro2d1íg
.pró2d1ig
.pro2d3ii.
.pró2d3ii.
.pro2d1im
.pro2d1ir
.pro2d1ír
.pro2d3is
.pro2d3ís
.pro2d5it
.pro2d5ít
.pro3d6iti
.pro3d6íti
.pro3d6ito
.pro3d6íto
.pro3d6itr
.pro3g2n
.pro3i4e
.pro3i4é
.pro3i4i
.pro3i4í
.pró3i4i
.pro3in
.propte2r3
.propté2r3
.pro3s2c
.pro6s5para
.pro5s2t
.pro5s4tan
.pro5s4tar
.pro4s3tit
.pro3u
.pseu2d3a
.pseudo3s4
.pseudó3s4
.p4t
.pulei4
.puléi4
.qua2m3o2b3
.quá2m3o2b3
.quattuo2r3
.que2m3a2d3m
.que2m3á2d3m
.quin2c3un
.quoa2d3usq
.quoa2d3úsq
.quo6d5l
.quo6n3iam
.quó6n3iam
.quo2t1an
.quo2t1án
.quo2t1enn
.quo2t1énn
.quo2t3li
.quó2t3li
.r2
.ra2y
.reco2n3i2u
.reco2n3i2ú
.re2d1ac
.re2d1ác
.re2d1ad
.re2d1ád
.re2d1am
.re2d1ám
.ré2d1am
.re3d4amn
.re3d4ámn
.re2d1an
.re2d1án
.re2d1ar
.re2d1ár
.re3d4ari
.re3d4ári
.re2d1a2u
.re2d1á2u
.re2d1ea
.ré2d1ea
.re2d1eá
.re2d1eg
.re2d1ég
.re2d1em
.re2d1ém
.re2d1eo
.ré2d1eo
.re2d1e3u
.re2d1e3ú
.ré2d1e3u
.re2d1h
.re2d1i.
.re2d1ib
.re2d1íb
.re3d2ic
.re2d1ien
.ré2d1ien
.re2d1ier
.re2d1íer
.re2d1iér
.re2d1ii
.ré2d1ii
.re2d1íi
.re2d1ií
.re2d1ig
.ré2d1ig
.re2d1im
.re2d1ím
.ré2d1im
.re4d3imi
.re2d1in
.re2d1ín
.redin2d3
.re2d1ir
.re2d1ír
.re2d5is
.re2d5it
.re2d5ít
.ré2d5it
.re2d1iv
.re2d1ív
.re2d1ol
.re2d1ól
.ré2d1ol
.re2d1op
.re2d1óp
.re2d1ord
.re2d1órd
.re3d2orm
.re2d1orn
.re2d1órn
.re2d1ul
.re2d1úl
.re2d1un
.re2d1ún
.re2d1uv
.re2d1úv
.ree2x
.re1ie
.re3i2ec
.re1in
.re3ips
.re3ite
.repa2u
.re3s2cr
.re3s2cu
.re3s2cú
.re3s4p
.ré3s4p
.re6s5pu4b3l
.re6s5pú4b3l
.re5s4ta
.re5s4tá
.re5s2tag
.re5s4ta2u
.re5s2ter
.re5s2tér
.re5s2tib
.re5s2tíb
.re5s2tic
.re6s3ticu
.re5s2til
.re5s2tin
.re5s2tín
.re5s2tip
.re5s2típ
.ré5s4tit
.re5s4tit
.re5s4tít
.re5s2to
.re5s4tr
.ré5s4tr
.retran2s1
.retrán2s1
.re3ul
.re3um
.rhe4u.
.s2
.sa2t1ag
.sa2t1ág
.sati2s1
.sa3ul.
.seme2t3ip
.semiam2b3
.semi3s4p
.se2m3un
.se2m3us
.se3s4cen
.ses2c1u4n
.si2c1ut
.sí2c1ut
.si3s2ten
.s2m
.sta3g2n
.su2b3
.sú2b3
.subam2b3
.subi4a
.subi4á
.subi4e
.subi4é
.subi4i
.subi4í
.súbi4i
.subi4u
.súbi4u
.subi4ú
.subne3u
.subné3u
.sub5s4cr
.sub3s4p
.subte2r3h
.subte2r3s4tr
.su3b4ul
.sú3b4ul
.su4b5ulc
.su4b5ult
.supe2r1a2b3l
.supe2r1á2b3l
.supe2r1a2b3n
.supe2r1a2b3und
.supe2r1a2b3únd
.supe2r1ac
.supe2r1ác
.supe2r1ad
.supe2r1ád
.supe2r1a2d1i2
.supe2r1á2d1i2
.supe3r2æ.
.supe2r1æ
.supe2r1af
.supe2r1áf
.supe2r1ag
.supe2r1ág
.supe2r1al
.supe2r1ál
.supe2r1amb
.supe2r1ámb
.supe2r1ap
.supe2r1arg
.supe2r1asc
.supe2r1asp
.supe2r1a5s6t
.supe2r1á5s6t
.supe3r2a6s7ti.
.supe3r2á6s7ti.
.supe3r2a6s7tis.
.supe3r2á6s7tis.
.supe2r1att
.supe2r1átt
.supe2r1au
.supe2r1ea
.supé2r1ea
.supe2r1éa
.supe2r1eá
.supe2r1eb
.supe2r1ed
.supe2r1éd
.supé2r1ed
.supe2r1ef
.supe2r1éf
.supe2r1eg
.supe2r1ég
.supe2r1el
.supe2r1él
.supe2r1emi
.supe2r1émi
.supe2r1emí
.supe3r2emini.
.supe3r2émini.
.supe2r1emo
.supe2r1émo
.supe2r1emó
.supe2r1en
.supe2r1én
.supe3r2ent
.súpe3r2ent
.supe3r2ént
.supe2r1eo
.supé2r1eo
.supe2r1eq
.supe2r1éq
.supe2r1er
.supe2r1ér
.supé2r1er
.supe3r2er.
.supe3r2ere.
.supe3r2ére.
.supe3r2éris.
.supe2r1es
.supé2r1es
.supe2r1és
.súpe2r1es
.supe2r3es.
.súpe2r3es.
.supe2r1ev
.supe2r1év
.supe2r1e2x1
.supe2r1é2x1
.supe2r3h
.supe2r1i2a
.supe2r1i2á
.supe2r1ib
.supe2r1íb
.supe2r1ie
.supe2r1ié
.supe2r1íe
.supe2r1i2ec
.supe2r1i2éc
.supe2r5ii
.supé2r5ii
.supe2r5ií
.supe2r5íi
.supe2r1il
.supe2r1íl
.supe2r1im
.supe2r1ím
.supe2r1i2n3
.supe2r1í2n3
.supe2r1i2n4d1u
.supe2r1í2n4d1u
.supe2r1i2n4d1ú
.superin5d2uc
.superin5d2úc
.superind3ui.
.superínd3ui.
.superin5d2ux
.superin5d2úx
.supe2r1i2n3i2e
.supe2r1i2n3i2é
.supe2r1i2n3i2i
.supe2r1i2n3i2í
.supe2r1í2n3i2i
.supe2r1i2n3s4t
.supe2r1í2n3s4t
.supe2r1ir
.supe2r1ír
.supe2r1iss
.supe2r1íss
.supe4r3it
.súpe4r3it
.supe4r3ít
.supé4r3it
.supe2r1i2u
.supe2r1i2ú
.supe3r2ius.
.supe2r1iv
.supe2r1ív
.supe2r1o2b3
.supe2r1ó2b3
.supe2r1oc
.supe2r1óc
.supe2r1op
.supe2r1óp
.supe2r1ord
.supe2r1órd
.supe2r3s4
.supé2r3s4
.supertran2s1
.supertrán2s1
.supe2r1u
.supe2r1ú
.supe3r2um.
.supe3r2us.
.supra3s2c
.supra3s4t
.suprá3s4t
.su5s4cr
.su3s4p
.sú3s4p
.su6s5pen
.su6s5pén
.t2
.ta2m3
.te2r1i2u
.terp2s
.te2r1un
.te2r1ún
.tetra3e2t
.tetra3g2n
.tetra3s2t
.the2o
.theo3g2n
.the3s2t
.the3ur
.thi3s2b
.tra1i2a
.tra1i2e
.tra1ii
.tran2s1
.trán2s1
.trans1a2b1
.trans1á2b1
.tran3s2acin
.tran3s2acín
.trans1a2d1
.trans1á2d1
.tran3s2cr
.tran3s2enn
.tran3s2énn
.tran3s2er
.trán3s2er
.tran3s2ér
.tran4s3eremini.
.tran4s3erémini.
.tran4s3eremur.
.tran4s3erémur.
.tran4s3erentur.
.tran4s3eréntur.
.tran4s3erer.
.trán4s3erer.
.tran3s2il
.trán3s2il
.tran3s2íl
.transi2u
.transi2ú
.tran3s2u
.trán3s2u
.tran3s2ú
.tran4s3ulm
.tra2n1ue
.tri3en
.uni3an
.uni3án
.u3n2i3uscu
.ute2r3ui
.va6s5p
.vá6s5p
.ve2l1ut
.vipe3r4
.vípe3r4
.vipé3r4
.x2
.z2
a1
á1
ab4s3tin
ab4s3tín
áb4s3tin
ab4s3trac
ab4s3trác
a1e.
æ1
ǽ1
æ3a
æ3á
ǽ3a
æ3e
æ3é
ǽ3e
æ3i
æ3í
ǽ3i
æ3o
æ3ó
ǽ3o
æ3u
æ3ú
ǽ3u
ai2e
ai2é
ai4i
a1i2m.
ai2o
ai2ó
ai6or.
a1is
a1ís
a3it.
á3it.
ai2u
ái2u
ai4unt.
a2m3ui
a2u
a5ú
á2u
a3um.
á3um.
a3us.
á3us.
2ax.
a2y
á2y
1b
2b.
2bb
2bd
2bh
2bj
b2l
2bm
2bn
2bp
b2r
2bs
b3s2t
2bt
bu3u
1c
4c.
2cc
2cd
c2h
2ch.
ch4l
4ch3m
4ch3n
cho3e
ch4r
4ch3t
ci3ent
ci3et
c4l
2cm
2cn
con5s4t
cón5s4t
2cq
c6r
cri6s5p
crí6s5p
2cs
2ct
cu3
cui4ús
cu4lc
cú4lc
cu4ln
cú4ln
cu4lp
cú4lp
cu4mb
cu4nc
cu4nt
cu4rs
cu4st
2cz
1d
2d.
d2æ.
d2am.
2dc
2dd
2df
2dg
2d3h
d4it.
2dl
2dm
2dn
2dp
2dq
d2r
2ds
du3u
4dv
2d3w
e1
é1
ë1
e3am.
é3am.
e5ant.
é5ant.
e3at.
é3at.
ei2a
ei2á
éi2a
ei2e
ei2é
éi2e
ei4i
ei2í
éi4i
ei4o
éi4o
e3is.
é3is.
ei2u
ei2ú
éi2u
ei4us.
éi4us.
e2l3ue
2em.
2es.
e2s3r
2et.
e2u
é2u
e3ú
e3um.
é3um.
e3umd
e3ump
e3unc
e3und
e3ung
e3unx
e3unt
é3unt
e3us.
é3us.
2ex.
e3y
1f
2f.
2ff
f2l
2fn
f2r
2ft
1g
2g.
2gd
ge3n2ua
2gf
2gg
g2l
2gm
g2n
g4ne.
g2r
2gs
1h
2h.
he3u.
2hp
2ht
hu2c5us
i1
í1
ï1
í5a
í5æ
í5e
i1el.
i3em.
i3ems.
i3ens.
i3ent.
i3es.
i3et.
í5i
i5i.
i3is.
i5it.
í5o
i2oi2u
i5or.
í5u
i3ud.
i3um.
i3unt.
i3ur.
i3us.
i2u2s3l
i2ú2s3l
i2u2s3v
i2ú2s3v
2i2x.
1j
1k
1l
4l.
langú3e
langu4ea
langu3era
langu3erá
langu3ere.
langu3ére.
langu3eri
langu3éri
langu3ero
langu3erunt.
langu3érunt.
langu4esc
langu3i.
lángu3i.
langu3imus.
langu3iss
langu3íss
langu3ist
langu3íst
langu5it.
lángu5it.
2lb
2lc
2ld
2lf
l3f2t
2lg
2lk
2ll
2lm
2ln
2lp
2lq
2lr
2ls
4lt
lu3i2a.
lú3i2a.
lu1un
lu1ún
4lv
4lz
1m
4m.
2mb
2mc
me4t3ips
2md
2mf
2ml
2mm
2mn
2mp
4mq
2mr
2ms
2mt
6mv
1n
2n.
2nb
2nc
nco3i
4nd
3ne.
2nf
2ng
ngu2a
ngu2á
ngu2æ
ngu2e
ngu2é
ngu4em.
ngu4es.
ngu4et.
ngu2i
ngu2í
ngu2i3o
ngu4is.
ngu4it.
ngu6o
ngu6ó
ngu2u
ngu2ú
ngui5us.
2nh
2nj
2nl
2nm
2nn
2np
2nq
2nr
2ns
n2s3f
n2s3m
2nt
nu3is.
4nv
2nx2
2nz
o1
ó1
ob3s2c
ob4s3cu
ob4s3cú
œ1
œ́1
oi2a
ói2a
oi2e
ói2e
oi2o
ói2o
oi2u
ói2u
o3um.
u2s3que
2ox.
o3y
1p
2p.
pe2r3e3u
pe2r3é3u
pé2r3e3u
pe2r3e3ú
p2h
2ph.
pha3el
ph2l
2phn
2php
ph3ph
ph8r
2pht
p2l
2pn
3p2neu
3p2néu
po2t3en
po2t3én
po2t3er
po2t3ér
po2t3es
po2t3és
4pp
p2r
pro3s4p
pró3s4p
2ps
3p2sic
4p3t
3p2tr
2pz
1qu4
1qui3a
1qui3á
1qui3æ
1qui3ǽ
1qui3e
1qui3é
1qui3o
1qui3ó
1qui5u
1qui5ú
qu6o.
qu6u
qu6um.
1r
4r.
r2æ.
ræ3s4p
2rb
2rc
2rd
2rf
2rg
r2h
rhe3us
ri3e.
r4iit.
r2i2m.
2rl
2rm
2rn
2rp
2rq
4r3r
2rs
2rt
ru3is.
ru3it.
r4us.
4rv
2r1x
2rz
1s
4s.
2sb
2sc
3s2cæ
3s2cǽ
3s2ce
3s2cé
3s2ci
3s2cí
3s2cœ
3s2cy
3s2cý
2sd
2s3dem.
2sf
2sg
2sl
2sm
2sn
2sne.
2sp
3s4parg
3s4párg
3s4pec
3s4péc
3s4perg
3s4pérg
3s4pern
3s4pérn
3s4pers
3s4pérs
3s4pex
3s4péx
3s4phæ
3s4phǽ
3s4pic
3s4píc
3s4pir
3s4pír
3s4plen
3s4plén
3s4pol
3s4pól
3s4pond
3s4pónd
3s4pons
3s4póns
3s4pum
3s4púm
2sq
2s3que.
2sr
4ss
s3se.
2st
2st.
s4t1k
s2t3l
2s3tn
2st3p
s2t3q
5s4trang
5s4tráng
5s4trep
5s4trép
5s4trigi
5s4trígi
5s4tring
5s4tríng
5s4trict
5s4tríct
5s4trom
5s4troph
s2t3s
s2t3t
su2b5s4tan
su3is.
2sv
1t
4t.
2tb
2tc
2td
2tf
2tg
t2h4
2th.
2th5m
2th5n
2th5p
2th5s
t2i2m.
ti3n2ui
ti1o.
2t1íps
t2l
2tm
2tn
2tp
2tq
t4r
tru3um.
tru3us.
2ts
2tt
u1
ú1
ü1
u3em.
u3es.
u3et.
2ui.
u3is.
u3it.
ui2u
ui4us.
u4lm
ú4lm
uo3u
uo3us
uo3ús
u5um.
u5us.
2ux.
1v
ve6s5p
vé6s5p
1x
2x.
x2it.
2xq
2xt
x2u3it.
x2ú3it.
x2um.
x2us.
x2y
xy4s3t
y1
ý1
y3a
y3e
y3i
y3o
y3u
y3æ
y3y
2y.
2ys.
2yx.
1z
2z.
2zz
8́
}

